#!/usr/bin/env python3

import subprocess
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_1_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1800.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits300.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits900.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2700.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_1_3600_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_MT_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_MT_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_12_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_12_9_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_10_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_10_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/AMS_100/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_1_out, 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_7_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_9_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_11_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_7_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_9_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_11_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_18_11_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_19_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_19_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_19_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_19_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits5.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_19_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_19_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_output_debug/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h.yaml', 'circuits_300.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h.yaml', 'circuits_300.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h.yaml', 'circuits_900.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h.yaml', 'circuits_1800.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h.yaml', 'circuits_2700.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_3_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h.yaml', 'circuits_3600.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_4_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_5_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_6_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_6_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_4_MT_v2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_24_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/40T_solenoid_1/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/40T_solenoid_3/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/valid_4_15_9/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/tree/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_25_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_25_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings2.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_15_3_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15b_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15b_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15b_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15b_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])

# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_15_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_15_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_27_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_1_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_27_insulated_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_27_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_27_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_27_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_27_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_27_2_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_23_FCS_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h.yaml', 'circuits_1800.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid.yaml', 'circuits_1800_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid_2.yaml', 'circuits_1800_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_output_new/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid_2.yaml', 'circuits_1800_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_2_output_new/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid_2.yaml', 'circuits_1800_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_c_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid.yaml', 'circuits_1800_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_d_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid.yaml', 'circuits_2700_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_e_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid2.yaml', 'circuits_2700_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_28_FCS/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid2.yaml', 'circuits_2700_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_28_FCS/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_28_FCS/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench4.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_28_FCS_1/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid2.yaml', 'circuits_2700_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid2.yaml', 'circuits_2700_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_375_Torch/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid2.yaml', 'circuits_2700.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_750_Torch/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid3.yaml', 'circuits_2700.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_750_Torch_1/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid3.yaml', 'circuits_2700.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_750_Torch/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_750_Torch/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_750_Torch/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_375_Torch/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/FCS_750_Torch_1/', 'solver.yaml', 'geometry.yaml', 'solver_stable.yaml', 'stable1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/CD_small_coils/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
subprocess.call(['python', 'NI_Coil_Solver_Torch.py', 'geometry/output/CD_small_coils/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/36_insulated_gianluca/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'ramp1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid3.yaml', 'circuits_2700.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench5.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench6.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench7.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench8.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench1.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench5.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench6.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench7.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_750/', 'solver.yaml', 'geometry.yaml', 'solver_quench.yaml', 'quench.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_375/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid2.yaml', 'circuits_2700_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/FCS_from_EXCEL_low_out/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid2.yaml', 'circuits_2700_PID_thermal.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_29_AMS_100_v3/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/6D_B7_NI/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid.yaml', 'circuits_2700_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_FCS_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver.py', 'geometry/output/test_geometry_23_thermal_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings_6h_pid.yaml', 'circuits_1800_PID.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits2.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits3.yaml'])
# subprocess.call(['python', 'NI_Coil_Solver_Light.py', 'geometry/output/test_geometry_15_output/', 'solver.yaml', 'geometry.yaml', 'solver_settings.yaml', 'circuits4.yaml'])
