#!/usr/bin/env python3

import subprocess
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_1.yaml', 'test_geometry_1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_1_1.yaml', 'test_geometry_1_1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_2.yaml', 'test_geometry_2_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_3.yaml', 'test_geometry_3_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4.yaml', 'test_geometry_4_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4_MT.yaml', 'test_geometry_4_MT_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4_MT_Cu1.yaml', 'test_geometry_4_MT_Cu1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4_MT_v2.yaml', 'test_geometry_4_MT_v2_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4_1.yaml', 'test_geometry_4_1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4_1_4mm.yaml', 'test_geometry_4_1_output_4mm'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yamlt_geometry_4_single.yaml', 'test_geometry_4_single_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4_single_4mm.yaml', 'test_geometry_4_single_output_4mm'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_4_1_3600.yaml', 'test_geometry_4_1_3600_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_5.yaml', 'test_geometry_5_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_6_AMS_100.yaml', 'test_geometry_6_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_7_AMS_100.yaml', 'test_geometry_7_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_8.yaml', 'test_geometry_8_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_10_AMS_100.yaml', 'AMS_100'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_11_presentation.yaml', 'test_geometry_11_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_12_screening_currents.yaml', 'test_geometry_12_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_12_1_screening_currents.yaml', 'test_geometry_12_1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_12_9_screening_currents.yaml', 'test_geometry_12_9_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_13_Eriks_test.yaml', 'test_geometry_13_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_14_screening_currents.yaml', 'test_geometry_14_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_15_screening_currents.yaml', 'test_geometry_15_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_15b_screening_currents.yaml', 'test_geometry_15b_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_15_screening_currents_1.yaml', 'geometry/output/test_geometry_15_3_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_16_screening_currents.yaml', 'test_geometry_16_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_17_screening_currents.yaml', 'test_geometry_17_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_18_test_SC_1.yaml', 'test_geometry_18_1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_18_test_SC_3.yaml', 'test_geometry_18_3_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_/18_test_SC_5.yaml', 'test_geometry_18_5_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_18_test_SC_7.yaml', 'test_geometry_18_7_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_18_test_SC_9.yaml', 'test_geometry_18_9_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_18_test_SC_11.yaml', 'test_geometry_18_11_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_19_psi.yaml', 'test_geometry_19_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_19_psi_2.yaml', 'test_geometry_19_2_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_19_psi_3.yaml', 'test_geometry_19_3_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_19_psi_single_coil.yaml', 'test_geometry_19_dp_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_21_6D_A1_forces.yaml', 'geometry/output/21_6D_A1_forces'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_21_6D_B5_B6.yaml', 'test_geometry_21_6D_B5_B6_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling.yaml', 'geometry/output/test_geometry_6D_cooling_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B_only.yaml', 'geometry/output/6D_cooling_B_only'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B8.yaml', 'geometry/output/6D_cooling_B8'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B7.yaml', 'geometry/output/test_geometry_6D_cooling_B7_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B7_no_map.yaml', 'geometry/output/test_geometry_6D_cooling_B7_no_map'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B6.yaml', 'test_geometry_6D_cooling_B6_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B5.yaml', 'test_geometry_6D_cooling_B5_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B4.yaml', 'geometry/output/6D_cooling_B4'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B3.yaml', 'geometry/output/6D_cooling_B3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B2.yaml', 'geometry/output/6D_cooling_B2'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B1.yaml', 'geometry/output/6D_cooling_B1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B7_2_cells.yaml', 'geometry/output/6D_cooling_B7_2_cells'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B7_3_cells.yaml', 'geometry/output/6D_cooling_B7_3_cells'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B7_3_cells_powered.yaml', 'geometry/output/6D_cooling_B7_3_cells_powered'])

# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B1_4_powered.yaml', 'geometry/output/6D_cooling_B1_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B1_4_non_powered.yaml', 'geometry/output/6D_cooling_B1_4_non_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B2_4_powered.yaml', 'geometry/output/6D_cooling_B2_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B2_4_non_powered.yaml', 'geometry/output/6D_cooling_B2_4_non_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B3_4_powered.yaml', 'geometry/output/6D_cooling_B3_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B3_4_non_powered.yaml', 'geometry/output/6D_cooling_B3_4_non_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B4_4_powered.yaml', 'geometry/output/6D_cooling_B4_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B4_4_non_powered.yaml', 'geometry/output/6D_cooling_B4_4_non_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B5_4_powered.yaml', 'geometry/output/6D_cooling_B5_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B5_4_non_powered.yaml', 'geometry/output/6D_cooling_B5_4_non_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B6_4_powered.yaml', 'geometry/output/6D_cooling_B6_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B6_4_non_powered.yaml', 'geometry/output/6D_cooling_B6_4_non_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B7_4_powered.yaml', 'geometry/output/6D_cooling_B7_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B7_4_non_powered.yaml', 'geometry/output/6D_cooling_B7_4_non_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B8_4_powered.yaml', 'geometry/output/6D_cooling_B8_4_powered'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/6D_cooling_B8_4_non_powered.yaml', 'geometry/output/6D_cooling_B8_4_non_powered'])

# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_22_ATLAS_5T_NbTi.yaml', 'test_geometry_22_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_1.yaml', 'test_geometry_23_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_1.yaml', 'test_geometry_23_thermal_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_2.yaml', 'test_geometry_23_2_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_3.yaml', 'test_geometry_23_3_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_3_5_b.yaml', 'geometry/output/test_geometry_23_FCS_2_output_new'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_3_5_c.yaml', 'test_geometry_23_FCS_c_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_3_5_d.yaml', 'test_geometry_23_FCS_d_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_3_5_e.yaml', 'test_geometry_23_FCS_e_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_3_5.yaml', 'geometry/output/test_geometry_23_FCS_output_new'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_28_FCS_1517A.yaml', 'geometry/output/test_geometry_28_FCS'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_28_FCS_1517A_1.yaml', 'geometry/output/test_geometry_28_FCS_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_29_AMS_100_v2.yaml', 'geometry/output/test_geometry_29_AMS_100_v2'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_29_AMS_100_v3.yaml', 'geometry/output/test_geometry_29_AMS_100_v3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_30_Patricia.yaml', 'geometry/output/Patricia_Coil'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_31_Patricia.yaml', 'geometry/output/Patricia_Coil_2'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_32_Patricia.yaml', 'geometry/output/Patricia_Coil_3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_33_6D_B7_NI.yaml', 'geometry/output/6D_B7_NI'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_34_FCS_750.yaml', 'geometry/output/FCS_750'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_34_FCS_750.yaml', 'geometry/output/FCS_750_Torch'])
subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_34_FCS_750_1.yaml', 'geometry/output/FCS_750_Torch_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_35_FCS_375.yaml', 'geometry/output/FCS_375'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_35_FCS_375.yaml', 'geometry/output/FCS_375_Torch'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_35_FCS_375_Paper.yaml', 'geometry/output/FCS_375_paper'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_36_insulated_gianluca.yaml', 'geometry/output/36_insulated_gianluca'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/CD_small_coils.yaml', 'geometry/output/CD_small_coils'])

# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_4.yaml', 'test_geometry_23_4_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometryI_23_FCS_5.yaml', 'test_geometry_23_5_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_23_FCS_6.yaml', 'test_geometry_23_6_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_hans.yaml', 'test_geometry_hans_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_24_1.yaml', 'test_geometry_24_1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/40T_solenoid_1.yaml', '40T_solenoid_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/40T_solenoid_2.yaml', '40T_solenoid_2'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/40T_solenoid_3.yaml', '40T_solenoid_3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/FCS_from_EXCEL.yaml', 'geometry/output/FCS_from_EXCEL'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/FCS_from_EXCEL_low_out.yaml', 'geometry/output/FCS_from_EXCEL_low_out'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/tree.yaml', 'tree'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_25_Emma.yaml', 'test_geometry_25_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_26_5T_Cryo.yaml', 'test_geometry_26_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_27_comp_200.yaml', 'test_geometry_27_2_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/test_geometry_27_comp_200_1.yaml', 'geometry/output/test_geometry_27_1_output'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'examples/legacy/input_yaml/test_geometry_27_comp_200_insulated.yaml', 'geometry/output/test_geometry_27_insulated_output'])

## Validations ##
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_1_1.yaml', 'valid_4_1_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_5_1.yaml', 'valid_4_5_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_10_1.yaml', 'valid_4_10_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_15_1.yaml', 'valid_4_15_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_20_1.yaml', 'valid_4_20_1'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_25_1.yaml', 'valid_4_25_1'])
#
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_1_3.yaml', 'valid_4_1_3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_5_3.yaml', 'valid_4_5_3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_10_3.yaml', 'valid_4_10_3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_15_3.yaml', 'valid_4_15_3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_20_3.yaml', 'valid_4_20_3'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_25_3.yaml', 'valid_4_25_3'])
#
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_1_5.yaml', 'valid_4_1_5'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_5_5.yaml', 'valid_4_5_5'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_10_5.yaml', 'valid_4_10_5'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_15_5.yaml', 'valid_4_15_5'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_20_5.yaml', 'valid_4_20_5'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_25_5.yaml', 'valid_4_25_5'])
#
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_1_7.yaml', 'valid_4_1_7'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_5_7.yaml', 'valid_4_5_7'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_10_7.yaml', 'valid_4_10_7'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_15_7.yaml', 'valid_4_15_7'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_20_7.yaml', 'valid_4_20_7'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_25_7.yaml', 'valid_4_25_7'])
#
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_1_9.yaml', 'valid_4_1_9'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_5_9.yaml', 'valid_4_5_9'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_10_9.yaml', 'valid_4_10_9'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_15_9.yaml', 'valid_4_15_9'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_20_9.yaml', 'valid_4_20_9'])
# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_25_9.yaml', 'valid_4_25_9'])

# subprocess.call(['python', 'NI_Coil_Geometry.py', 'geometry/input_yaml/valid_4_1_1.yaml', 'valid_4_1_1'])

