#!/usr/bin/env python3

import subprocess

# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 1/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 1/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 2/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 2/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 2/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 2/', 'IR', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 3/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 3/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 3/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 4/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 4/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 4/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 5/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 5/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 5/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 6/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 6/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 6/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 7/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 7/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-29 - 0.1 - 7/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 1/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 1/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 2/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 2/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 2/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 3/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 3/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-08-30 - 0.1 - 3/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-04 - 0.1 - 2/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-04 - 0.1 - 2/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-04 - 0.1 - 2/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-04 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-04 - 0.1 - 1/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-04 - 0.1 - 1/', 'Physt', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_Cu1_output/results/result - 2023-09-05 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_Cu1_output/results/result - 2023-09-05 - 0.1 - 1/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_Cu1_output/results/result - 2023-09-05 - 0.1 - 1/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_Cu1_output/results/result - 2023-09-05 - 0.1 - 2/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_Cu1_output/results/result - 2023-09-05 - 0.1 - 2/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_Cu1_output/results/result - 2023-09-05 - 0.1 - 2/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-05 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-05 - 0.1 - 1/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_output/results/result - 2023-09-05 - 0.1 - 1/', 'I_density', '270', 'False', 'True', 'False'])

# For Bernardo
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_2_output/results/result - 2023-08-25 - 0.1 - 2', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_2_output/results/result - 2023-08-31 - 0.1 - 1', 'Fr_density', '270', 'False', 'True', 'True'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'geometry/output/test_geometry_23_2_output/results/result - 2023-08-31 - 0.1 - 1', 'Fz_density', '270', 'False', 'True', 'True'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_2_output/results/result - 2023-08-31 - 0.1 - 1', 'T', '270', 'False', 'True', 'True'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_2_output/results/result - 2023-08-31 - 0.1 - 1', 'I_density', '270', 'False', 'True', 'True'])

# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_v2_output/results/result - 2023-09-20 - 0.1 - 2/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_3_output/results/result - 2023-09-20 - 0.1 - 2/', 'Prad', '270', 'True', 'False', 'True'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_4_MT_v2_output/results/result - 2023-09-20 - 0.1 - 2/', 'T', '270', 'False', 'True', 'False'])

# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_24_1_output/results/result - 2023-10-03 - 0.1 - 2/', 'Fz_density', '270', 'True', 'True', 'True'])

# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_2_output/results/result - 2023-10-05 - 0.1 - 1/', 'I_density', '270', 'True', 'True', 'True'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_3_output/results/result - 2023-10-06 - 0.1 - 1/', 'Fr_density', '270', 'True', 'True', 'True'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_3_output/results/result - 2023-10-06 - 0.1 - 1/', 'T', '270', 'True', 'True', 'True'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_3_output/results/result - 2023-10-06 - 0.1 - 1/', 'I_density', '270', 'True', 'True', 'True'])

# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_2_output/results/result - 2023-10-09 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_3_output/results/result - 2023-10-09 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_5_output/results/result - 2023-10-13 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_5_output/results/result - 2023-10-13 - 0.1 - 1/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_6_output/results/result - 2023-10-23 - 0.1 - 1/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_6_output/results/result - 2023-10-23 - 0.1 - 1/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_10_output/results/result - 2023-11-01 - 0.1 - 2/', 'I_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/AMS_100/results/result - 2023-12-05 - 0.1 - 7/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/40T_solenoid_3/results/result - 2023-11-24 - 0.1 - 2/', 'T', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/40T_solenoid_2/results/result - 2023-11-24 - 0.1 - 2/', 'Fr_density', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/valid_4_15_9/results/result - 2023-11-30 - 0.1 - 3/', 'I_density', '270', 'False', 'True', 'False'])

# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/FCS_750/results/result - 2024-07-31 - 0.1 - 17/', 'Fr_density', '270', 'True', 'True', 'True', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/FCS_750/results/result - 2024-07-31 - 0.1 - 21/', 'Fr_density', '270', 'True', 'True', 'True', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/FCS_750/results/result - 2024-07-31 - 0.1 - 22/', 'Fr_density', '270', 'True', 'True', 'True', '50'])

# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/tree/results/result - 2023-12-05 - 0.1 - 3/', 'II', '270', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_15_output/results/result - 2023-12-11 - 0.1 - 5/', 'I_density', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_15_output/results/result - 2023-12-11 - 0.1 - 6/', 'I_density', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_15_output/results/result - 2023-12-11 - 0.1 - 7/', 'I_density', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_15_output/results/result - 2023-12-11 - 0.1 - 8/', 'I_density', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_FCS_output/results/result - 2024-03-09 - 0.1 - 3/', 'T', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_FCS_output/results/result - 2024-03-09 - 0.1 - 3/', 'I_density', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_FCS_c_output/results/result - 2024-03-26 - 0.1 - 1/', 'T', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_23_FCS_e_output/results/result - 2024-04-02 - 0.1 - 1/', 'I_density', '180', 'False', 'True', 'False'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_28_FCS/results/result - 2024-05-24 - 0.1 - 1', 'T', '180', 'False', 'True', 'False', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_28_FCS/results/result - 2024-05-28 - 0.1 - 4', 'T', '180', 'False', 'True', 'False', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/FCS_750/results/result - 2024-07-31 - 0.1 - 21', 'T', '180', 'False', 'True', 'False', '100'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/FCS_750/results/result - 2024-07-31 - 0.1 - 17', 'T', '180', 'False', 'True', 'False', '100'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_29_AMS_100_v2/results/result - 2024-07-03 - 0.1 - 5', 'T', '180', 'False', 'True', 'False', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/test_geometry_29_AMS_100_v3/results/result - 2024-09-23 - 0.1 - 2', 'T', '180', 'False', 'True', 'False', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/36_insulated_gianluca/results_light/result - 2024-11-12 - 43', 'I_density', '180', 'True', 'True', 'True', '50'])
subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/36_insulated_gianluca/results_light/result - 2024-11-12 - 14', 'I_density', '180', 'True', 'True', 'True', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/36_insulated_gianluca/results_light/result - 2024-11-12 - 9', 'I_density', '180', 'True', 'True', 'True', '50'])
# subprocess.call(['python', 'Results_to_Paraview.py', 'C:/Tim Mulder/CERNBox/Staff - TE-MPE-PE/Projects/ni-coils/geometry/output/FCS_from_EXCEL_low_out/results/result - 2024-05-28 - 0.1 - 1', 'I_density', '180', 'False', 'True', 'False', '50'])




